@@ -2,18 +2,18 @@
 #'
 #' Running prediction on data frame of remote database table, without needing to
 #' load original packages used to fit model.
-#' 
+#'
 #' @param object An [orbital] object.
 #' @param new_data A data frame or remote database table.
 #' @param ... Not currently used.
 #'
 #' @details
 #' Using this function should give identical results to running `predict()` or
-#' `bake()` on the orginal object. 
-#' 
-#' The prediction done will only return prediction colunms, a opposed to 
+#' `bake()` on the orginal object.
+#'
+#' The prediction done will only return prediction colunms, a opposed to
 #' returning all modified functions as done with [orbital_inline()].
-#' 
+#'
 #' @returns A modified data frame or remote database table.
 #'
 #' @examplesIf rlang::is_installed(c("recipes", "tidypredict", "workflows"))
@@ -35,11 +35,13 @@
 #' predict(orbital_obj, mtcars)
 #' @export
 predict.orbital_class <- function(object, new_data, ...) {
-  rlang::check_dots_empty()
-  res <- dplyr::mutate(new_data, !!!orbital_inline(object))
+	rlang::check_dots_empty()
+	res <- dplyr::mutate(new_data, !!!orbital_inline(object))
 
-  pred_name <- names(object)[length(object)]
-  res <- dplyr::select(res, dplyr::any_of(pred_name))
+	pred_name <- attr(object, "pred_names")
+	if (!is.null(pred_name)) {
+		res <- dplyr::select(res, dplyr::any_of(pred_name))
+	}
 
-  res
+	res
 }
